pub struct FormatFeatureFlags(/* private fields */);Expand description
Implementations
Sourceimpl FormatFeatureFlags
impl FormatFeatureFlags
Sourceimpl FormatFeatureFlags
impl FormatFeatureFlags
Sourcepub const SAMPLED_IMAGE: Self
pub const SAMPLED_IMAGE: Self
Format can be used for sampled images (SAMPLED_IMAGE and COMBINED_IMAGE_SAMPLER descriptor types)
Sourcepub const STORAGE_IMAGE: Self
pub const STORAGE_IMAGE: Self
Format can be used for storage images (STORAGE_IMAGE descriptor type)
Sourcepub const STORAGE_IMAGE_ATOMIC: Self
pub const STORAGE_IMAGE_ATOMIC: Self
Format supports atomic operations in case it is used for storage images
Sourcepub const UNIFORM_TEXEL_BUFFER: Self
pub const UNIFORM_TEXEL_BUFFER: Self
Format can be used for uniform texel buffers (TBOs)
Sourcepub const STORAGE_TEXEL_BUFFER: Self
pub const STORAGE_TEXEL_BUFFER: Self
Format can be used for storage texel buffers (IBOs)
Sourcepub const STORAGE_TEXEL_BUFFER_ATOMIC: Self
pub const STORAGE_TEXEL_BUFFER_ATOMIC: Self
Format supports atomic operations in case it is used for storage texel buffers
Sourcepub const VERTEX_BUFFER: Self
pub const VERTEX_BUFFER: Self
Format can be used for vertex buffers (VBOs)
Sourcepub const COLOR_ATTACHMENT: Self
pub const COLOR_ATTACHMENT: Self
Format can be used for color attachment images
Sourcepub const COLOR_ATTACHMENT_BLEND: Self
pub const COLOR_ATTACHMENT_BLEND: Self
Format supports blending in case it is used for color attachment images
Sourcepub const DEPTH_STENCIL_ATTACHMENT: Self
pub const DEPTH_STENCIL_ATTACHMENT: Self
Format can be used for depth/stencil attachment images
Sourcepub const BLIT_DST: Self
pub const BLIT_DST: Self
Format can be used as the destination image of blits with vkCmdBlitImage
Sourcepub const SAMPLED_IMAGE_FILTER_LINEAR: Self
pub const SAMPLED_IMAGE_FILTER_LINEAR: Self
Format can be filtered with VK_FILTER_LINEAR when being sampled
Sourceimpl FormatFeatureFlags
Generated from ‘VK_IMG_filter_cubic’
impl FormatFeatureFlags
Generated from ‘VK_IMG_filter_cubic’
Sourcepub const SAMPLED_IMAGE_FILTER_CUBIC_IMG: Self
pub const SAMPLED_IMAGE_FILTER_CUBIC_IMG: Self
Format can be filtered with VK_FILTER_CUBIC_IMG when being sampled
Sourceimpl FormatFeatureFlags
Generated from ‘VK_KHR_video_decode_queue’
impl FormatFeatureFlags
Generated from ‘VK_KHR_video_decode_queue’
pub const VIDEO_DECODE_OUTPUT_KHR: Self
pub const VIDEO_DECODE_DPB_KHR: Self
Sourceimpl FormatFeatureFlags
Generated from ‘VK_KHR_maintenance1’
impl FormatFeatureFlags
Generated from ‘VK_KHR_maintenance1’
pub const TRANSFER_SRC_KHR: Self = Self::TRANSFER_SRC
pub const TRANSFER_DST_KHR: Self = Self::TRANSFER_DST
Sourceimpl FormatFeatureFlags
Generated from ‘VK_EXT_sampler_filter_minmax’
impl FormatFeatureFlags
Generated from ‘VK_EXT_sampler_filter_minmax’
pub const SAMPLED_IMAGE_FILTER_MINMAX_EXT: Self = Self::SAMPLED_IMAGE_FILTER_MINMAX
Sourceimpl FormatFeatureFlags
Generated from ‘VK_KHR_acceleration_structure’
impl FormatFeatureFlags
Generated from ‘VK_KHR_acceleration_structure’
pub const ACCELERATION_STRUCTURE_VERTEX_BUFFER_KHR: Self
Sourceimpl FormatFeatureFlags
Generated from ‘VK_KHR_sampler_ycbcr_conversion’
impl FormatFeatureFlags
Generated from ‘VK_KHR_sampler_ycbcr_conversion’
pub const MIDPOINT_CHROMA_SAMPLES_KHR: Self = Self::MIDPOINT_CHROMA_SAMPLES
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER_KHR: Self = Self::SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER_KHR: Self = Self::SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_KHR: Self = Self::SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE_KHR: Self = Self::SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE
pub const DISJOINT_KHR: Self = Self::DISJOINT
pub const COSITED_CHROMA_SAMPLES_KHR: Self = Self::COSITED_CHROMA_SAMPLES
Sourceimpl FormatFeatureFlags
Generated from ‘VK_EXT_filter_cubic’
impl FormatFeatureFlags
Generated from ‘VK_EXT_filter_cubic’
pub const SAMPLED_IMAGE_FILTER_CUBIC_EXT: Self = Self::SAMPLED_IMAGE_FILTER_CUBIC_IMG
Sourceimpl FormatFeatureFlags
Generated from ‘VK_EXT_fragment_density_map’
impl FormatFeatureFlags
Generated from ‘VK_EXT_fragment_density_map’
pub const FRAGMENT_DENSITY_MAP_EXT: Self
Sourceimpl FormatFeatureFlags
Generated from ‘VK_KHR_fragment_shading_rate’
impl FormatFeatureFlags
Generated from ‘VK_KHR_fragment_shading_rate’
pub const FRAGMENT_SHADING_RATE_ATTACHMENT_KHR: Self
Sourceimpl FormatFeatureFlags
Generated from ‘VK_KHR_video_encode_queue’
impl FormatFeatureFlags
Generated from ‘VK_KHR_video_encode_queue’
pub const VIDEO_ENCODE_INPUT_KHR: Self
pub const VIDEO_ENCODE_DPB_KHR: Self
Sourceimpl FormatFeatureFlags
Generated from ‘VK_VERSION_1_1’
impl FormatFeatureFlags
Generated from ‘VK_VERSION_1_1’
Sourcepub const TRANSFER_SRC: Self
pub const TRANSFER_SRC: Self
Format can be used as the source image of image transfer commands
Sourcepub const TRANSFER_DST: Self
pub const TRANSFER_DST: Self
Format can be used as the destination image of image transfer commands
Sourcepub const MIDPOINT_CHROMA_SAMPLES: Self
pub const MIDPOINT_CHROMA_SAMPLES: Self
Format can have midpoint rather than cosited chroma samples
Sourcepub const SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER: Self
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER: Self
Format can be used with linear filtering whilst color conversion is enabled
Sourcepub const SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER: Self
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER: Self
Format can have different chroma, min and mag filters
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT: Self
pub const SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE: Self
Sourcepub const COSITED_CHROMA_SAMPLES: Self
pub const COSITED_CHROMA_SAMPLES: Self
Format can have cosited rather than midpoint chroma samples
Sourceimpl FormatFeatureFlags
Generated from ‘VK_VERSION_1_2’
impl FormatFeatureFlags
Generated from ‘VK_VERSION_1_2’
Sourcepub const SAMPLED_IMAGE_FILTER_MINMAX: Self
pub const SAMPLED_IMAGE_FILTER_MINMAX: Self
Format can be used with min/max reduction filtering