pub struct ImageCreateFlags(/* private fields */);Expand description
Implementations
Sourceimpl ImageCreateFlags
impl ImageCreateFlags
Sourceimpl ImageCreateFlags
impl ImageCreateFlags
Sourcepub const SPARSE_BINDING: Self
pub const SPARSE_BINDING: Self
Image should support sparse backing
Sourcepub const SPARSE_RESIDENCY: Self
pub const SPARSE_RESIDENCY: Self
Image should support sparse backing with partial residency
Sourcepub const SPARSE_ALIASED: Self
pub const SPARSE_ALIASED: Self
Image should support constant data access to physical memory ranges mapped into multiple locations of sparse images
Sourcepub const MUTABLE_FORMAT: Self
pub const MUTABLE_FORMAT: Self
Allows image views to have different format than the base image
Sourcepub const CUBE_COMPATIBLE: Self
pub const CUBE_COMPATIBLE: Self
Allows creating image views with cube type from the created image
Sourceimpl ImageCreateFlags
Generated from ‘VK_NV_corner_sampled_image’
impl ImageCreateFlags
Generated from ‘VK_NV_corner_sampled_image’
pub const CORNER_SAMPLED_NV: Self
Sourceimpl ImageCreateFlags
Generated from ‘VK_KHR_device_group’
impl ImageCreateFlags
Generated from ‘VK_KHR_device_group’
pub const SPLIT_INSTANCE_BIND_REGIONS_KHR: Self = Self::SPLIT_INSTANCE_BIND_REGIONS
Sourceimpl ImageCreateFlags
Generated from ‘VK_KHR_maintenance1’
impl ImageCreateFlags
Generated from ‘VK_KHR_maintenance1’
pub const TYPE_2D_ARRAY_COMPATIBLE_KHR: Self = Self::TYPE_2D_ARRAY_COMPATIBLE
Sourceimpl ImageCreateFlags
Generated from ‘VK_KHR_maintenance2’
impl ImageCreateFlags
Generated from ‘VK_KHR_maintenance2’
pub const BLOCK_TEXEL_VIEW_COMPATIBLE_KHR: Self = Self::BLOCK_TEXEL_VIEW_COMPATIBLE
pub const EXTENDED_USAGE_KHR: Self = Self::EXTENDED_USAGE
Sourceimpl ImageCreateFlags
Generated from ‘VK_EXT_sample_locations’
impl ImageCreateFlags
Generated from ‘VK_EXT_sample_locations’
pub const SAMPLE_LOCATIONS_COMPATIBLE_DEPTH_EXT: Self
Sourceimpl ImageCreateFlags
Generated from ‘VK_KHR_sampler_ycbcr_conversion’
impl ImageCreateFlags
Generated from ‘VK_KHR_sampler_ycbcr_conversion’
pub const DISJOINT_KHR: Self = Self::DISJOINT
Sourceimpl ImageCreateFlags
Generated from ‘VK_KHR_bind_memory2’
impl ImageCreateFlags
Generated from ‘VK_KHR_bind_memory2’
Sourceimpl ImageCreateFlags
Generated from ‘VK_EXT_fragment_density_map’
impl ImageCreateFlags
Generated from ‘VK_EXT_fragment_density_map’
pub const SUBSAMPLED_EXT: Self
Sourceimpl ImageCreateFlags
Generated from ‘VK_AMD_extension_317’
impl ImageCreateFlags
Generated from ‘VK_AMD_extension_317’
pub const RESERVED_16_AMD: Self
Sourceimpl ImageCreateFlags
Generated from ‘VK_EXT_extension_377’
impl ImageCreateFlags
Generated from ‘VK_EXT_extension_377’
pub const RESERVED_18_EXT: Self
Sourceimpl ImageCreateFlags
Generated from ‘VK_EXT_extension_394’
impl ImageCreateFlags
Generated from ‘VK_EXT_extension_394’
pub const RESERVED_394_EXT: Self
Sourceimpl ImageCreateFlags
Generated from ‘VK_QCOM_fragment_density_map_offset’
impl ImageCreateFlags
Generated from ‘VK_QCOM_fragment_density_map_offset’
pub const FRAGMENT_DENSITY_MAP_OFFSET_QCOM: Self
Sourceimpl ImageCreateFlags
Generated from ‘VK_VERSION_1_1’
impl ImageCreateFlags
Generated from ‘VK_VERSION_1_1’
pub const ALIAS: Self
Sourcepub const SPLIT_INSTANCE_BIND_REGIONS: Self
pub const SPLIT_INSTANCE_BIND_REGIONS: Self
Allows using VkBindImageMemoryDeviceGroupInfo::pSplitInstanceBindRegions when binding memory to the image
Sourcepub const TYPE_2D_ARRAY_COMPATIBLE: Self
pub const TYPE_2D_ARRAY_COMPATIBLE: Self
The 3D image can be viewed as a 2D or 2D array image
pub const BLOCK_TEXEL_VIEW_COMPATIBLE: Self
pub const EXTENDED_USAGE: Self
pub const DISJOINT: Self